     {% load i18n%}
<div class="row">
  <center><h1>{{titulu}} </h1></center>

    {% for xxx in produtu %}
                    <div class="col-md-4">
                               <div class="service-widget">
                                <div class="post-media " style="visibility: visible;">
                                    <img src="{{xxx.produtu.imagen_main.url}}" style="width:100%; height: 200px;  object-fit: cover;" alt="" class="img-responsive img-rounded">
                                </div>
                                <div class="service-dit">
                                  <center>
                                  
                                  <a href='#' data-toggle='modal' data-id="{{xxx.produtu.id}}" id='butaun_modal_detallu'  data-target= '#modal_detallu' ><h5>  {{xxx.titulu}} </h5></a> 
                                 <h3 style="padding: 0px 0 12px;">
                                  <a href='#' data-toggle='modal' data-id="{{xxx.produtu.id}}" id='butaun_modal_detallu'  data-target= '#modal_detallu' >{% trans "Pressu" %}  $ {{xxx.produtu.presu}}</a>
          
                                </h3>
  
                            </center>
                              </div>
                         </div>
                     </div>
  
      {% endfor %}
      
  
  
    
                 
                </div>